#
# spec file for package perl-AnyEvent
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-AnyEvent
Version:        7.02
Release:        41.1
%define cpan_name AnyEvent
Summary:        the DBI of event loop programming
License:        GPL-1.0+ or Artistic-1.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/AnyEvent/
Source:         http://www.cpan.org/authors/id/M/ML/MLEHMANN/%{cpan_name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
#BuildRequires: perl(AnyEvent)
#BuildRequires: perl(AnyEvent::AIO)
#BuildRequires: perl(AnyEvent::Debug)
#BuildRequires: perl(AnyEvent::DNS)
#BuildRequires: perl(AnyEvent::Handle)
#BuildRequires: perl(AnyEvent::Impl::Perl)
#BuildRequires: perl(AnyEvent::Impl::Qt::Io)
#BuildRequires: perl(AnyEvent::Impl::Qt::Timer)
#BuildRequires: perl(AnyEvent::IO)
#BuildRequires: perl(AnyEvent::IO::IOAIO)
#BuildRequires: perl(AnyEvent::IO::Perl)
#BuildRequires: perl(AnyEvent::Log)
#BuildRequires: perl(AnyEvent::Loop)
#BuildRequires: perl(AnyEvent::Socket)
#BuildRequires: perl(AnyEvent::Strict)
#BuildRequires: perl(AnyEvent::TLS)
#BuildRequires: perl(AnyEvent::Util)
#BuildRequires: perl(Cocoa::EventLoop)
#BuildRequires: perl(EV) >= 4.00
#BuildRequires: perl(Event)
#BuildRequires: perl(Event::Lib)
#BuildRequires: perl(FLTK) >= 0.532
#BuildRequires: perl(Glib) >= 1.210
#BuildRequires: perl(Guard)
#BuildRequires: perl(IO::AIO) >= 4.13
#BuildRequires: perl(IO::Async::Loop) >= 0.33
#BuildRequires: perl(Irssi)
#BuildRequires: perl(JSON)
#BuildRequires: perl(JSON::XS)
#BuildRequires: perl(Net::DNS::Resolver)
#BuildRequires: perl(Net::SSLeay)
#BuildRequires: perl(POE)
#BuildRequires: perl(Qt)
#BuildRequires: perl(Qt::isa)
#BuildRequires: perl(Qt::slots)
#BuildRequires: perl(Socket6)
#BuildRequires: perl(Tk)
Recommends:     perl(Async::Interrupt) >= 1
Recommends:     perl(EV) >= 4
Recommends:     perl(Guard) >= 1.02
Recommends:     perl(JSON) >= 2.09
Recommends:     perl(JSON::XS) >= 2.2
Recommends:     perl(Net::SSLeay) >= 1.33
Recommends:     perl(Task::Weaken)
%{perl_requires}

%description
the AnyEvent manpage provides a uniform interface to various event loops.
This allows module authors to use event loop functionality without forcing
module users to use a specific event loop implementation (since more than
one event loop cannot coexist peacefully).

The interface itself is vaguely similar, but not identical to the the Event
manpage module.

During the first call of any watcher-creation method, the module tries to
detect the currently loaded event loop by probing whether one of the
following modules is already loaded: the EV manpage, the AnyEvent::Loop
manpage, the Event manpage, the Glib manpage, the Tk manpage, the
Event::Lib manpage, the Qt manpage, the POE manpage. The first one found is
used. If none are detected, the module tries to load the first four modules
in the order given; but note that if the EV manpage is not available, the
pure-perl the AnyEvent::Loop manpage should always work, so the other two
are not normally tried.

Because AnyEvent first checks for modules that are already loaded, loading
an event model explicitly before first using AnyEvent will likely make that
model the default. For example:

   use Tk;
   use AnyEvent;

   # .. AnyEvent will likely default to Tk

The _likely_ means that, if any module loads another event model and starts
using it, all bets are off - this case should be very rare though, as very
few modules hardcode event loops without announcing this very loudly.

The pure-perl implementation of AnyEvent is called 'AnyEvent::Loop'. Like
other event modules you can load it explicitly and enjoy the high
availability of that event loop :)

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes COPYING mktest README util

%changelog
* Tue Sep  4 2012 coolo@suse.com
- updated to 7.02
  - AnyEvent::Util::run_cmd could block indefinitely (analyzed and test
    program by Yorhel).
  - verified that AnyEvent::Socket follows RFC5952.
  - try to parse "ADDR#PORT" in addition to "ADDR PORT".
* Wed May 30 2012 coolo@suse.com
- it's not noarch
* Fri May 25 2012 coolo@suse.com
- updated to 7.01
  - fail with EPROTO in AnyEvent::Handle wqhen TLS is requested but
    not available, instead of throwing an exception.
  - use File::Spec to get the tmpdir in t/*, to avoid needless
    failures on (most, not mine :) windows boxes.
  - new handle read types: tls_detect and tls_autostart.
  - child watchers are broken in POE 1.352 (also many earlier
    versions) and there seems to be no way to work around it, as POE
    itself is inherently racy. Document this regression and add a delay
    in t/68_poe_03_child.t for the time being.
  - new module AnyEvent::IO, that is a frontend to either a pure-perl
    synchronous I/O implementation (AnyEvent::IO::Perl), or to the
    asynchronous I/O extension IO::AIO (AnyEvent::IO::IOAIO).
  - load /etc/hosts only when DNS has no answer.
  - stat /etc/hosts on every access and reload it if it changed.
  - load /etc/hosts via AnyEvent::IO - potentially asynchronous.
  - fix a buggy croak in the dh parameter reading in AnyEvent::TLS.
  - AnyEvent::Log log_to_file and log_to_path now use AnyEvent::IO. As
    a side effect, they now use true appending as opposed to libc
    appending, and the file might not have been opened when the function
    returns.
  - the default logging level was not properly documented in a variety of
    places, this has hopefully been rectified.
  - updated uts46data.pl for unicode 6.1.0.
  - made log messages generated by AnyEvent submodules not
    include the package name anymore, as it will be logged
    by default already.
  - upgrade to the trick used by common-sense 3.5 to work
    around extra warning torture/breakage under perl 5.15.x.
  - log messages by anyevent are now ucfirst, are usually full
    sentences and do no longer include the package name.
  - the storable read type would sometimes throw an exception instead
    of causing EBADMSG (analyzed by Maxime Soulé).
  - work around a bug in openssl 1.0.1 which enforces a minimum rsa
    keysize (reported by Paul Howarth).
  - documented Rocco fabricating statements about AnyEvent and me.
* Fri Feb 10 2012 coolo@suse.com
- updated to 6.14
  - AnyEvent::Impl::Tk was broken due to a mysterious "die" inside,
    probably an editing mistake (reported by Darin McBride).
  - AnyEvent::Util::fork_call checked for POSIX availability in the wrong way,
    causing it to fail if POSIX wasn't loaded already (analysed by Rock Power).
  - AnyEvent::Handle::push_read (line => did pass $1 directly, so
    regex-matching inside the callback would change the parameter, despite
    $1 being dynamically scoped per-block. this perl bug is now being
    worked around (testcase by Cindy Wang).
  - $! was clobbered by subsequent calls in tcp_connect, due to
    the postpone not saving/restoring it (analyzed by Richard Garnish).
  - Tk cannot create windows when tainted unless you set a title, so
    set a dummy title for AnyEvent's dummy mainwindow. How dummy.
  - escape any nonprintable/nonascii characters when stringifying
    backtraces.
  - log the reason loading an interface module fails to load at level debug.
* Fri Nov 18 2011 coolo@suse.com
- update to 6.1
  - INCOMPATIBLE CHANGE: the default log level is now "4" (error
    and above), and some messages inside AnyEvent have been elevated
    to higher log levels to print by default.
  ... see Changes
* Mon Sep 19 2011 coolo@suse.com
- updated to 6.02
  - log_to_syslog now accepts facility strings.
  - log_to_syslog would not allow facilities - "$facility|$level"
  * literally* means that string. sheesh.
  - the CPAN parser got confused and thought we provide Sys::Syslog, try
    to work around.
  - renamed AnyEvent::Impl::FLTK2 to FLTK.
  ... for more see Changes
* Thu Aug 25 2011 chris@computersalat.de
- fix deps
  o build for RHEL, CentoS, SLE_10 (Unknown tag: Recommends)
- cpanspec
* Sat Jun 11 2011 pascal.bleser@opensuse.org
- switch to bm.pl, as cpanspec created an RPM that didn't provide
  perl(AnyEvent)
* Sat Jun 11 2011 pascal.bleser@opensuse.org
- update to 5.34:
  * AE::TLS didn't support both cert_file and key at the same time, due to some
    copy&paste bug
  * improve AE::Handle timeout documentation slightly
- changes from 5.33:
  * AnyEvent::Handle on_connect_error - do not try to destroy a handle object
    when it's already gone
  * update idna algorithm(s) to UTS#46 version 6.0.0
  * preserve trailing dot in idn_to_ascii - testsuite says to preserve, uts46
    says it's an error, and testsuite makes more sense
  * remove leading dots in idn_to_ascii - testsuite says to remove, uts46 says
    it's an error, and testsuite makes more sense
  * fixed a bug in idn ignored character processing
- changes from 5.31:
  * work around a POE bug where POE would first poll for new events and invoke
    handlers BEFORE handling the message queue
  * fix parsing of "domain" statement in resolv.conf
  * stop_read now does just that in TLS mode; see its documentation for caveats
  * update to common::sense 3.4 warning set (some warnings in perl impose an
    arbitrary 32kb limit on regex matches, which affects AnyEvent::Handle)
  * AE::Handle had a broken rbuf_max method and missing wbuf_max method
  * new experimental AE::Handle::resettls method
- changes from 5.3:
  * major IOAsync patch by Paul Evans - 0.33 is required, as the major issues
    with IO::Async have been solved in that version, including the availabilty
    of a default loop!
  * implement new wbuf_max parameter for AnyEvent::Handle
  * added Cocoa::EventLoop backend
  * set CLOEXEC flag on parent-side fd's in AnyEvent::Util::run_cmd, to avoid
    leaking them to any child processes
  * try to force files into the arch-dependend lib directory, for the
    half-"turly obsessive compulsive person"(s) that depend on it
- changes from 5.29:
  * convert EV backend to EV 4.00 API (so better upgrade EV too)
  * AE::Handle: implement dynamic read_size adjustment, add max_read_size
    parameter, reduce default read_size to 2048
  * add some FAQ entries for servers and/or on_eof vs. on_error
  * reduce memory usage slightly when connect was used in AE::Handle
  * work around more segfaults in Tk
  * document tls_ctx => undef as valid
  * detect WNOHANG value at compiletime
  * include some probably linux-only support for building AnyEvent as part of
    the perl core
  * make AnyEvent::Strict truly optional (in case somebody builds a minimal perl...)
- changes from 5.28:
  * due to a glitch, AnyEvent's internal getprotobyname wasn't actually used in
    tcp_server
  * implement AnyEvent::CondVar->new method, which was documented but missing
  * support autoloading of read types in unshift_read
  * AnyEvent::Strict: do the test for invalid fh arguments differently,
    resulting in more informative error messages
  * new AnyEvent::FAQ manpage
  * clarify that you can actually call push_read etc. in on_read
  * put keys and certs in /tmp, not into the current directory and document
    this in the SECURITY CONSIDERATIONS sections of AnyEvent::TLS
  * support ";" as resolv.conf comment character in AnyEvent::DNS
  * AnyEvent::Handle now croaks when negative timeouts are passed
  * add a shitload of TCP_xxx sockopt name constants to AnyEvent::Util,
    undocumented, but who knows when they might come in handy
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul  6 2010 chris@computersalat.de
- update to 5.271
  - backport to perl 5.8.x.
- 5.27   Sun Jun  6 12:12:05 CEST 2010
  - postpone differently in AnyEvent::Socket now, as
    when not, canceling the connection attempt might fail
    (found by Felix Antonius Wilhelm Ostmann).
  - explicitly check for non-stream sockets in AE::Handle, too many
    clueless people fell into the trap of this somehow working.
  - simplified and reworked the "OTHER MODULES" section.
  - better/more condvar examples.
- spec created by cpanspec 1.78
* Wed May  5 2010 lnussel@suse.de
- don't package empty vendorarch directory
* Thu Apr 29 2010 lnussel@suse.de
- make noarch
* Thu Apr 29 2010 lnussel@suse.de
- new version 2.261
  - AF_INET6 was not properly used from Socket6 during configuration
  time (found by Andy Grundman).
  - don't generate spurious readyness notifications when select
  returns EINTR in the pure perl backend (analysed and testcase
  by Bas Denissen).
  - give same examples in SYNOPSIS sections of AnyEvent and AE.
  - provider faster implementations for AE::time/now/now_update for
  EV and Perl backends.
  - provide faster AE::cv and AE::time implementations for all
  backends.
  - no longer support lower/mixed-case signal names (this was
  never documented nor universally supported).
  - some more memory-optimisations, and somewhat less messy
  code to cope with both AnyEvent and AE APIs.
* Tue Mar 16 2010 lnussel@suse.de
- new version 5.251
  - fix a race condition in AnyEvent::Handle that would cause
    a "bio_read: unsupported method" error (in _another_
    ssl connection) after user code threw an exception.
  - added AnyEvent::Handle->destroyed method.
  - speed up AnyEvent::Socket::format_address and ::format_ipv6.
  - the AnyEvent::Util::fh_nonblocking function worked only
    by lucky accident on win32.
  - smaller and faster AnyEvent::Util::fh_nonblocking.
  - when the (required!) Time::HiRes module is missing, AnyEvent
    did not fall back to built-in time properly.
  - do not load Fcntl at runtime, saving memory and loading time.
  - precompile a number of constants and use them instead of runtime
    detection and eval.
  - free detection code after detection and similar memory optimisations.
  - Perl backend timer interval best effort drift has been improved
    (ame algorithm as EV).
  - update unicode idna mapping table.
* Fri Feb 26 2010 lnussel@suse.de
- new version 5.24
  - JSON dependency optional
  - IDN support
  - IPv6 support
* Fri Sep  4 2009 chris@computersalat.de
- spec mods
  o added header
  o added perl-macros
  o cleanup
- fixed deps
  o Requires
    perl = perl_version
    perl(JSON) >= 2.09
  o added Recommends
    perl(EV) >= 3.4
    perl(JSON::XS) >= 2.2
    perl(Async::Interrupt) >= 1.0
    perl(Net::SLeay) >= 1.33
    perl(Guard) >= 1.02
* Thu Jun 11 2009 jw@novell.com
- initial build of AnyEvent-4.352.tar.gz
